# temBoard Agent

This project contains the service monitoring and managing one PostgreSQL instance.

Please refer to [temBoard](https://labs.dalibo.com/temboard) main project to see the full picture.
